@@ -5,7 +5,7 @@ use strict;
 use Exporter;
 use Carp;
 
-our $VERSION = '0.01_02';
+our $VERSION = '0.01_03';
 
 our @ISA = 'Exporter';
 our @EXPORT_OK = qw( is_undef is_defined is_bool is_value is_value is_ref is_str
@@ -171,7 +171,7 @@ Simo::Constrain - Constrain functions for Simo;
 
 =head1 VERSION
 
-Version 0.01_02
+Version 0.01_03
 
 Simo::Constrain is experimental stage. some function will be change.
 
@@ -199,201 +199,147 @@ All function can be exported.
 
 =head1 FUNCTIONS
 
-The followin is constrain function.
+The following is constrain functions.
 
 If function return false, error message is set to $@.
 
+If first argument is omitted, all functions receive $_ as first argument.
+
 =head2 is_undef
     
-    if it is undef, return true.
-    my $val = shift || $_;
-    !defined($val) or $@ = "must be undef.( $val is bad )", return 0;
-    return 1;
-    
+If it is undef, return true.
+
 =cut
 
 =head2 is_defined
 
-    my $val = shift || $_;
-    defined($val) or $@ = "must be defined.( undef is bad )", return 0;
-    return 1;
+If it is defined, return true.
     
 =cut
 
 =head2 is_bool
 
-    my $val = shift || $_;
-    !defined($val) || $val eq "" || "$val" eq '1' || "$val" eq '0'
-        or $@ = "must be boolean.( $val is bad )", return 0;
-    return 1;
+If it is boolean, return true.
+
+( undef, "", 0, and 1 ) are boolean.
     
 =cut
 
 =head2 is_value
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    !ref($val) or $@ = "must be value.( $val is bad )", return 0;
-    return 1;
-    
+If it is value, return true.
+
+Not reference value is value.
+
 =cut
 
 =head2 is_str
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    !ref($val) or $@ = "must be string.( $val is bad )", return 0;
-    return 1;
-    
+If it is string, return true.
+
+Not reference value is string. This is same as value.
+
 =cut
 
 =head2 is_num
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
+If it is number, return true.
+
+If Scalar::Util::looks_like_number return true, it is number.
 
-    require Scalar::Util;
-    is_value( $val ) && Scalar::Util::looks_like_number( $val )
-        or $@ = "must be number.( $val is bad )", return 0;
-    return 1;
-    
 =cut
 
 =head2 is_int
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_num( $val ) && "$val" =~ /^-?[0-9]+$/
-        or $@ = "must be integer.( $val is bad )", return 0;
-    return 1;
-    
+If it is integer, return true.
+
+If regexp /^-?[0-9]+$/ is matched. it is integer.
+
 =cut
 
 =head2 is_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    ref($val) or $@ = "must be reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is reference, return true.
+
 =cut
 
 =head2 is_scalar_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_ref( $val ) && ref($val) eq 'SCALAR'
-        or $@ = "must be scalar reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is scalar reference, return true.
+
 =cut
 
 =head2 is_array_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_ref( $val ) && ref($val) eq 'ARRAY'
-        or $@ = "must be array reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is array reference, return true.
+
 =cut
 
 =head2 is_hash_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_ref( $val ) && ref($val) eq 'HASH'
-        or $@ = "must be hash reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is hash reference, return true.
+
 =cut
 
 =head2 is_code_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_ref( $val ) && ref($val) eq 'CODE'
-        or $@ = "must be code reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is code reference, return true.
+
 =cut
 
 =head2 is_regexp_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_ref( $val ) && ref($val) eq 'Regexp'
-        or $@ = "must be regexp reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is regular expression reference, return true.
+
 =cut
 
 =head2 is_glob_ref
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_ref( $val ) && ref($val) eq 'GLOB'
-        or $@ = "must be glob reference.( $val is bad )", return 0;
-    return 1;
-    
+If it is glob reference, return true.
+
 =cut
 
 =head2 is_file_handle
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_glob_ref( $val ) && Scalar::Util::openhandle($val)
-        or $@ = "must be file handle.( $val is bad )", return 0;
-    return 1;
-    
+If it is file handle, return true.
+
+If Scalar::Util::openhandle is true, it is file handle.
+
 =cut
 
 =head2 is_object
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    require Scalar::Util;
-    is_ref( $val ) && Scalar::Util::blessed($val) && Scalar::Util::blessed($val) ne 'Regexp'
-        or $@ = "must be object.( $val is bad )", return 0;
-    return 1;
-    
+If it is objcet, return true.
+
+Blessed value is object, except qr//.
+
 =cut
 
 =head2 is_class_name
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    is_str( $val ) && $val =~ /^(\w+::)*\w+$/ or $@ = "must be class name.( $val is bad )", return 0;
-    return 1;
-    
+If it is class name, return true.
+
+If /^(\w+::)*\w+$/ is matched, it is class name.
+
 =cut
 
 =head2 blessed
 
-    my $val = shift || $_;
-    is_defined( $val ) or return 0;
-    require Scalar::Util;
-    Scalar::Util::blessed( $val ) or $@ = "must be blessed.( $val is bad )", return 0;
-    return 1;
-    
+If it is blessed, return true.
+
 =cut
 
 =head2 isa
 
-    my $val = @_ eq 2 ? shift : $_;
-    my $class = shift;
-    croak "class name of isa must be defined" unless defined $class;
-    croak "class name of isa is invalid" unless is_class_name( $class ); 
-    
-    is_defined( $val ) or return 0;
-    eval{ $val->isa( $class ) } or $@ = "must inherit $class.( $val is bad )", return 0;
-    return 1;
-    
+If it inherit a Class, return true.
+
+    sub author{ ac constrain => sub{ isa 'Person' }, }
+
 =cut
 
 =head1 AUTHOR
 
-Yuki, C<< <kimoto.yuki at gmail.com> >>
+Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
 
 =head1 BUGS
 
@@ -401,9 +347,6 @@ Please report any bugs or feature requests to C<bug-simo-constrain at rt.cpan.or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Simo-Constrain>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -441,6 +384,10 @@ Most of Simo::Constrain functions is compatible of Moose::Util::TypeConstraints
 
 L<Moose>,L<Moose::Util::TypeConstraints>
 
+Scalar::Util is used in Simo::Constrain
+
+L<Scalar::Util>
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Yuki, all rights reserved.
